;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "gt" "20250727.230"
  "Translation framework, configurable and scalable."
  '((emacs "28.1")
    (pdd   "0.2.3"))
  :url "https://github.com/lorniu/gt.el"
  :commit "f9febd8583ea482f72139e02f440f3972502f5a2"
  :revdesc "f9febd8583ea"
  :keywords '("convenience")
  :authors '(("lorniu" . "lorniu@gmail.com"))
  :maintainers '(("lorniu" . "lorniu@gmail.com")))
